package com.ruoyi.business.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.database.domain.NonWorkingDayDrinkingReport;
import com.ruoyi.database.domain.dto.ApprovaltDto;
import com.ruoyi.database.service.NonWorkingDayDrinkingReportService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;

/**
 * @Description NonWorkingDayDrinkingReportController
 * @Author lijingtong
 * @Date 2025-05-29
 */

@Api(tags = "非工作日饮酒报备单")
@RestController
@RequestMapping("NonWorkingDayDrinkingReport")
@RequiredArgsConstructor
public class NonWorkingDayDrinkingReportController extends BaseController {
    private final NonWorkingDayDrinkingReportService nonWorkingDayDrinkingReportService;
    @ApiOperation("查询非工作日饮酒报备单")
    @GetMapping("")
    public TableDataInfo query(NonWorkingDayDrinkingReport nonWorkingDayDrinkingReport) {
        startPage();
        DateTimeFormatter dtf = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
        QueryWrapper<NonWorkingDayDrinkingReport> queryWrapper = new QueryWrapper<>(nonWorkingDayDrinkingReport);
        queryWrapper.orderByDesc("create_time");
        String fTime = nonWorkingDayDrinkingReport.getFTime();
        String eTime = nonWorkingDayDrinkingReport.getETime();
        LocalDateTime time = LocalDateTime.parse(fTime);
        LocalDateTime time1 = LocalDateTime.parse(eTime);
        if  (fTime != null && fTime != null) {
            queryWrapper.between("create_time", time, time1);
        }
        List<NonWorkingDayDrinkingReport> list = nonWorkingDayDrinkingReportService.list(queryWrapper);
        long count = nonWorkingDayDrinkingReportService.count(queryWrapper);
        return getDataTableEnhance(list, count);
    }

    @ApiOperation("查询非工作日饮酒报备单详情")
    @GetMapping("/detail/{id}")
    public AjaxResult detail(@PathVariable Long id) {
        NonWorkingDayDrinkingReport nonWorkingDayDrinkingReport = nonWorkingDayDrinkingReportService.getById(id);
        return AjaxResult.success(nonWorkingDayDrinkingReport);
    }

    @ApiOperation("新增或修改非工作日饮酒报备单 传id为修改 不传id为新增")
    @PostMapping("/add")
    public AjaxResult add(@RequestBody NonWorkingDayDrinkingReport nonWorkingDayDrinkingReport) {
        SysUser user = getLoginUser().getUser();
        if (nonWorkingDayDrinkingReport.getId() == null) {
            nonWorkingDayDrinkingReport.setCreateBy(user.getNickName());
            boolean result = nonWorkingDayDrinkingReportService.save(nonWorkingDayDrinkingReport);
            if (!result) {
                return AjaxResult.error("新增非工作日inksReport失败");
            }
            return AjaxResult.success(result);
        }else {
            nonWorkingDayDrinkingReport.setUpdateBy(user.getNickName());
            boolean result = nonWorkingDayDrinkingReportService.updateById(nonWorkingDayDrinkingReport);
            if (!result) {
                return AjaxResult.error("修改非工作日inksReport失败");
            }
            return AjaxResult.success(result);
        }

    }

    @ApiOperation("删除非工作日饮酒报备单")
    @DeleteMapping("/delete/{id}")
    public AjaxResult delete(@PathVariable Long id) {
        boolean result = nonWorkingDayDrinkingReportService.removeById(id);
        if (!result) {
            return AjaxResult.error("删除非工作日inksReport失败");
        }
        return AjaxResult.success(result);
    }


    @ApiOperation("审批非工作日饮酒报备单")
    @PostMapping("/approval")
    public AjaxResult approval(@RequestBody ApprovaltDto dto) {
        Long id = dto.getId();
        Integer state = dto.getState();
        NonWorkingDayDrinkingReport nonWorkingDayDrinkingReport =  nonWorkingDayDrinkingReportService.getById(id);
        nonWorkingDayDrinkingReport.setState(state);
        boolean result = nonWorkingDayDrinkingReportService.updateById(nonWorkingDayDrinkingReport);
        if (!result) {
            return AjaxResult.error("审批非工作日饮酒报备单失败");
        }
        return AjaxResult.success("审批非工作日饮酒报备单成功");
    }
}
